%global srcname pip
%global bashcompdir %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)

Summary:        The Python package installer
Name:           python-%{srcname}
Version:        22.1.1
Release:        3%{?dist}
License:        MIT and Python and ASL 2.0 and BSD and ISC and LGPLv2 and MPLv2.0 and (ASL 2.0 or BSD)
URL:            https://pip.pypa.io/
Source0:        https://github.com/pypa/pip/archive/%{version}/%{srcname}-%{version}.tar.gz
Patch0001:      0001-dummy-certifi.patch

BuildRequires:  python3-devel python3-setuptools python3-pyyaml python3-wheel
BuildRequires:  python3-sphinx python3-sphinx-inline-tabs python3-sphinx-copybutton
BuildRequires:  python3-myst-parser bash-completion ca-certificates
# For test suite
BuildRequires:  python3-pytest python3-scripttest python3-virtualenv
BuildRequires:  python3-werkzeug python3-freezegun git
BuildArch:      noarch

%description
Pip is the package installer for Python. You can use pip to install 
packages from the Python Package Index and other indexes.

%package -n python3-%{srcname}
Summary:        The Python package installer

Requires:       ca-certificates
Requires:       python3-libs >= 3.10.0-2
Recommends:     python3-setuptools
Recommends:     (libcrypt.so.1()(64bit) if python3(x86-64))
Provides:       pip = %{version}-%{release}

%description -n python3-%{srcname}
Pip is the package installer for Python. You can use pip to install
packages from the Python Package Index and other indexes.

%package -n     %{python_wheel_pkg_prefix}-%{srcname}-wheel
Summary:        The pip wheel
Requires:       ca-certificates
Recommends:     (libcrypt.so.1()(64bit) if python3(x86-64))

%description -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
A Python wheel of pip to use with venv.

%prep
%autosetup -p1 -n %{srcname}-%{version}

rm -fv src/pip/_vendor/certifi/*.pem
sed -i '/"sphinxcontrib.towncrier",/d' docs/html/conf.py
ln -s %{python_wheel_dir} tests/data/common_wheels
grep -lr "^#\!/usr/bin/env python" src/pip/_vendor/ | xargs sed -i "1d"

find src/pip/_vendor -name "*.exe" -type f -exec rm -fv {} \;
sed -i '/\.exe/d' setup.py

%build
%py3_build_wheel
export PYTHONPATH=./src/
sphinx-build-3 -b man -c docs/html docs/man docs/build/man

%install
%{python3} dist/%{srcname}-%{version}-py3-none-any.whl/pip install \
    --root %{buildroot} \
    --no-deps \
    --disable-pip-version-check \
    --progress-bar off \
    --verbose \
    --ignore-installed \
    --no-warn-script-location \
    --no-index \
    --no-cache-dir \
    --find-links dist \
    'pip==%{version}'

pushd docs/build/man
install -d %{buildroot}%{_mandir}/man1
for MAN in *1; do
install -pm0644 $MAN %{buildroot}%{_mandir}/man1/$MAN
for pip in "pip3" "pip-3" "pip%{python3_version}" "pip-%{python3_version}"; do
echo ".so $MAN" > %{buildroot}%{_mandir}/man1/${MAN/pip/$pip}
done
done
popd

mkdir -p %{buildroot}%{bashcompdir}
PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{buildroot}%{_bindir}/pip completion --bash \
    > %{buildroot}%{bashcompdir}/pip3

sed -i -e "s/^\\(complete.*\\) pip\$/\\1 pip pip{,-}{3,%{python3_version}}/" \
    -e s/_pip_completion/_pip3_completion/ \
    %{buildroot}%{bashcompdir}/pip3

ln -s ./pip%{python3_version} %{buildroot}%{_bindir}/pip-%{python3_version}
ln -s ./pip-%{python3_version} %{buildroot}%{_bindir}/pip-3

echo rpm > %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/INSTALLER
rm %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/RECORD

mkdir -p %{buildroot}%{python_wheel_dir}
install -p dist/%{srcname}-%{version}-py3-none-any.whl -t %{buildroot}%{python_wheel_dir}

%check
sed -i '/import tomli_w/d' tests/functional/test_pep517.py
sed -i '/import tomli_w/d' tests/functional/test_pep660.py
not_test='not network and
          not test_from_link_vcs_with_source_dir_obtains_commit_id and
          not test_from_link_vcs_without_source_dir and
          not test_should_cache_git_sha'
%pytest \
    --deselect tests/functional --deselect tests/lib/test_lib.py \
    -k "$(echo $not_test)"

%files -n python3-%{srcname}
%doc README.rst
%license %{python3_sitelib}/pip-%{version}.dist-info/LICENSE.txt
%{python3_sitelib}/pip*
%dir %{bashcompdir}
%{bashcompdir}/pip3
%{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip-3
%{_bindir}/pip%{python3_version}
%{_bindir}/pip-%{python3_version}
%{_mandir}/man1/pip.*
%{_mandir}/man1/pip-*.*
%{_mandir}/man1/pip3.*
%{_mandir}/man1/pip3-*.*

%files -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
%license LICENSE.txt
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{srcname}-%{version}-py3-none-any.whl

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu May 26 2022 Xiaojie Chen <jackxjchen@tencent.com> 22.1.1-1
- Initial build
